==> module-ui-colfix-1.0.0.tgz: package/ui-colfix.es6.js <==
import $ from 'jquery';
import UIView from '@gec/ui-view';

export default class UIColFix extends UIView {
    constructor(options = {}) {
        super($.extend({
            className: 'ui-colfix'
        }, options));
        var $element = this.$el;


        var stickBottom = $element.data('stick') == "bottom",
            child = $element.data('child');
        var isIpad = /iPad/.test(navigator.userAgent);
        var cfscroll = function(e) {

            if (isIpad) {
                return;
            }

            if (e.data.$parent.height() - e.data.$element.height() < 50) {
                e.data.$element.css('top', '').removeClass('ui-colfixed').removeClass('ui-colabsoluted');
                return;
            }
            var hw = $('html').scrollTop() || $(window).scrollTop();
            if ($parent.outerHeight(true) < $element.outerHeight(true) || $element.data("con") && ($element.outerHeight(true) + $element.outerHeight(true) / 2) > $parent.outerHeight(true)) {
                $element.removeClass('ui-colabsoluted ui-colfixed');
                return false;
            }
            e.data.itop = e.data.$i.offset().top;
            e.data.ptop = e.data.$parent.offset().top + e.data.$parent.outerHeight(true) - (e.data.$element.outerHeight(true));
            var rest = stickBottom ? $element.outerHeight(true) - $(window).height() : 0;
            if (hw > e.data.itop + rest) {

                if (child) e.data.$element.css('width', $element.parent().outerWidth());
                if (hw < e.data.ptop + rest) {
                    e.data.$element.css('top', 0).addClass('ui-colfixed').removeClass('ui-colabsoluted').css('top', rest * -1);
                } else
                    e.data.$element.css('top', e.data.ptop).addClass('ui-colabsoluted').removeClass('ui-colfixed');
            } else {
                e.data.$element.css({ 'top': '' }).removeClass('ui-colfixed').removeClass('ui-colabsoluted');
                if (child) e.data.$element.css({ 'width': 'inherit' });
            }

        };
        var itop, ptop, $parent;
        $element.before('<i/>');

        setTimeout(function() {
            $parent = $($element.data('fixto') || $element.parent());
            itop = $element.data('done', true).offset().top;
            ptop = $parent.offset().top + $parent.outerHeight(true) - ($element.outerHeight(true));

            $(window).off('scroll.libui', cfscroll).on('scroll.libui touchmove', { $element: $element, $parent: $parent, $i: $element.prev() }, cfscroll);
            $(window).trigger('scroll.libui');

        }, 300);


    }
}

UIColFix.dataSetName = 'UIColFix';
$.fn.UIColFix = function() {
    return this.each(function() {
        var $el = $(this);
        var colfix = new UIColFix({
            el: $el
        }).saveDataset();
        $el.data("api", colfix);
    });
};

==> module-ui-colfix-1.0.1.tgz: package/ui-colfix.es6.js <==
import $ from 'jquery';
import UIView from '@gec/ui-view';

export default class UIColFix extends UIView {
    constructor(options = {}) {
        super($.extend({
            className: 'ui-colfix'
        }, options));
        var $element = this.$el;

        var stickBottom = $element.data('stick') == "bottom",
            child = $element.data('child');
        var isIpad = /iPad/.test(navigator.userAgent); // hc :(
        var cfscroll = function(e) {

            if (isIpad) {
                return;
            }

            if (e.data.$parent.height() - e.data.$element.height() < 50) {
                e.data.$element.css('top', '').removeClass('ui-colfixed').removeClass('ui-colabsoluted');
                return;
            }
            var hw = $('html').scrollTop() || $(window).scrollTop();
            if ($parent.outerHeight(true) < $element.outerHeight(true) || $element.data("con") && ($element.outerHeight(true) + $element.outerHeight(true) / 2) > $parent.outerHeight(true)) {
                $element.removeClass('ui-colabsoluted ui-colfixed');
                return false;
            }
            e.data.itop = e.data.$i.offset().top;
            e.data.ptop = e.data.$parent.offset().top + e.data.$parent.outerHeight(true) - (e.data.$element.outerHeight(true));
            var rest = stickBottom ? $element.outerHeight(true) - $(window).height() : 0;
            if (hw > e.data.itop + rest) {

                if (child) e.data.$element.css('width', $element.parent().outerWidth());
                if (hw < e.data.ptop + rest) {
                    e.data.$element.css('top', 0).addClass('ui-colfixed').removeClass('ui-colabsoluted').css('top', rest * -1);
                } else
                    e.data.$element.css('top', e.data.ptop).addClass('ui-colabsoluted').removeClass('ui-colfixed');
            } else {
                e.data.$element.css({ 'top': '' }).removeClass('ui-colfixed').removeClass('ui-colabsoluted');
                if (child) e.data.$element.css({ 'width': 'inherit' });
            }

        };
        var itop, ptop, $parent;
        $element.before('<i/>');

        setTimeout(function() {
            $parent = $($element.data('fixto') || $element.parent());

            itop = $element.data('done', true).offset().top;
            ptop = $parent.offset().top + $parent.outerHeight(true) - ($element.outerHeight(true));

            $(window).off('scroll.libui', cfscroll).on('scroll.libui touchmove', { $element: $element, $parent: $parent, $i: $element.prev() }, cfscroll);
            $(window).trigger('scroll.libui');

        }, 300);




    }
}

UIColFix.dataSetName = 'UIColFix';
$.fn.UIColFix = function() {
    return this.each(function() {
        var $el = $(this);
        var colfix = new UIColFix({
            el: $el
        }).saveDataset();
        $el.data("api", colfix);
    });
};
